@@ -1,8 +1,8 @@
-from xvg.core import Renderer
 import xml.etree.ElementTree as ET
+from xvg.core import *
 
 
-class SVGRenderer(Renderer):
+class SVGRenderer():
     """
     A Scalable Vector Graphics (SVG) renderer.
         Tutorial: https://developer.mozilla.org/en-US/docs/Web/SVG/Tutorial
@@ -33,10 +33,13 @@ class SVGRenderer(Renderer):
         viewH = context.scale.y
         root.set('viewBox', f'{viewX} {viewY} {viewW} {viewH}')
 
-        encoding = 'utf-8'
-        return headXML.encode(encoding) + headDOC.encode(encoding) + ET.tostring(root, encoding)
+        encoding = 'utf-8'  # TODO use class
+        result = headXML.encode(encoding)\
+            + headDOC.encode(encoding)\
+            + ET.tostring(root, encoding)
 
-    def renderFile(self, context, path):
-        """ Renders the image and writes the result file """
-        with open(path, "wb") as file:
-            file.write(self.render(context))
+        return FileData(
+            value=result,
+            type=SVGFileType(),
+            name=context.name
+        )
